"use strict";
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.filterBlocks = exports.filterDynamicBlocks = void 0;
const utils_1 = require("../utils");
function filterDynamicBlocks(options) {
    var _a;
    const { blocksList, blocksThemes = {}, currentTheme, name } = options, filterOptions = __rest(options, ["blocksList", "blocksThemes", "currentTheme", "name"]);
    const { blocks = [], defaultBlocks } = (_a = blocksThemes[currentTheme]) !== null && _a !== void 0 ? _a : {};
    const defaultBlocksByName = (0, utils_1.getDefaultBlocksByName)(defaultBlocks, name);
    const hasNoBlocks = !blocks.length || !defaultBlocksByName.length;
    if (hasNoBlocks) {
        return [];
    }
    const mergedBlockList = [...blocksList, ...blocks];
    const dictionaryBlocks = (0, utils_1.parsingArrayToDictionary)(mergedBlockList);
    return defaultBlocksByName.reduce((resultBlocks, block) => {
        return filterBlocksReducer(resultBlocks, block, dictionaryBlocks, filterOptions);
    }, []);
}
exports.filterDynamicBlocks = filterDynamicBlocks;
function filterBlocks(options) {
    var _a;
    const { blocksList, blocksThemes = {}, currentTheme } = options, filterOptions = __rest(options, ["blocksList", "blocksThemes", "currentTheme"]);
    const { blocks = [] } = (_a = blocksThemes[currentTheme]) !== null && _a !== void 0 ? _a : {};
    const mergedBlockList = [...blocksList, ...blocks];
    const dictionaryBlocks = (0, utils_1.parsingArrayToDictionary)(mergedBlockList);
    const blocksListForFilter = (0, utils_1.getBlocksForFilter)(blocksList, blocks);
    return blocksListForFilter.reduce((filteredBlocks, block) => {
        const blockId = typeof block === 'object' ? block.id : block;
        if (blockId) {
            const blockData = dictionaryBlocks[blockId];
            if ((0, utils_1.isBlockSupported)(blockData, filterOptions)) {
                filteredBlocks.push(blockData);
            }
        }
        return filteredBlocks;
    }, []);
}
exports.filterBlocks = filterBlocks;
function filterBlocksReducer(blocks, block, dictionaryBlocks, options) {
    const parsedBlockData = (0, utils_1.parseBlockData)(block);
    const dictionaryBlock = dictionaryBlocks[parsedBlockData.id];
    if (dictionaryBlock) {
        const { clm, path } = dictionaryBlock;
        const blockData = Object.assign({ clm, path }, parsedBlockData);
        if ((0, utils_1.isBlockSupported)(blockData, options)) {
            blocks.push(blockData);
        }
    }
    return blocks;
}
//# sourceMappingURL=index.js.map